summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/checkbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/checkbox.h')
-rw-r--r--kalarm/lib/checkbox.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/kalarm/lib/checkbox.h b/kalarm/lib/checkbox.h
index 389e66231..6b6985cd6 100644
--- a/kalarm/lib/checkbox.h
+++ b/kalarm/lib/checkbox.h
@@ -39,21 +39,22 @@
*
* @author David Jarvie <software@astrojar.org.uk>
*/
-class CheckBox : public QCheckBox
+class CheckBox : public TQCheckBox
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Constructor.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit CheckBox(TQWidget* parent, const char* name = 0);
+ explicit CheckBox(TQWidget* tqparent, const char* name = 0);
/** Constructor.
* @param text Text to display.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- CheckBox(const TQString& text, TQWidget* parent, const char* name = 0);
+ CheckBox(const TQString& text, TQWidget* tqparent, const char* name = 0);
/** Returns true if the widget is read only. */
bool isReadOnly() const { return mReadOnly; }
/** Sets whether the check box is read-only for the user. If read-only,
@@ -79,7 +80,7 @@ class CheckBox : public QCheckBox
protected slots:
void slotClicked();
private:
- TQWidget::FocusPolicy mFocusPolicy; // default focus policy for the QCheckBox
+ TQWidget::FocusPolicy mFocusPolicy; // default focus policy for the TQCheckBox
TQWidget* mFocusWidget; // widget to receive focus when button is clicked on
bool mFocusWidgetEnable; // enable focus widget before setting focus
bool mReadOnly; // value cannot be changed
@@ -39,21 +39,22 @@
public:
/** Constructor.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
@@ -39,21 +39,22 @@
/** Constructor.
* @param text Text to display.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/